@@ -32,6 +32,7 @@ use NewsExtractor::SiteSpecificExtractor::www_hkcnews_com;
 use NewsExtractor::SiteSpecificExtractor::www_epochtimes_com;
 use NewsExtractor::SiteSpecificExtractor::www_ttv_com_tw;
 use NewsExtractor::SiteSpecificExtractor::www_idn_com_tw;
+use NewsExtractor::SiteSpecificExtractor::www_fountmedia_io;
 use NewsExtractor::SiteSpecificExtractor::UDN;
 use NewsExtractor::SiteSpecificExtractor::ETtoday;
 use NewsExtractor::SiteSpecificExtractor::ChinaTimes;
@@ -82,6 +83,7 @@ use constant {
         'newnet.tw' => 'NewsExtractor::SiteSpecificExtractor::newnet_tw',
         'www.ttv.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_ttv_com_tw',
         'www.idn.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_idn_com_tw',
+        'www.fountmedia.io' => 'NewsExtractor::SiteSpecificExtractor::www_fountmedia_io',
     },
     CSSRuleSetByHost => {
         'www.taiwannews.com.tw' => {
